@@ -9,7 +9,7 @@ use Carp;
 use Try::Tiny;
 use Data::Dumper;
 
-our $VERSION = '0.001';
+our $VERSION = '0.008';
 
 register logged_in_user => sub
 {
@@ -626,6 +626,19 @@ register delete_permission => sub
     return $provider->delete_permission( $params, $opts );
 };
 
+register provider => sub
+{
+    my $dsl    = shift;
+    my $params = shift;
+    my $opts   = shift;
+    my $app    = $dsl->app;
+    my $conf   = plugin_setting();
+
+    my $provider = _provider( $dsl, $conf, _try_realm( $app, $opts ) );
+
+    return $provider;
+};
+
 sub _require_login
 {
     my $dsl     = shift;
@@ -790,7 +803,7 @@ Dancer2::Plugin::Auth::YARBAC - Yet Another Role Based Access Control Framework
 
 =head1 VERSION
 
-version 0.001
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -851,11 +864,11 @@ L<Dancer2::Plugin::Auth::YARBAC::Provider::Database>.
 
 YARBAC is a role based user authentication and authorisation framework for Dancer2 apps. 
 Designed with security and a medium to large user base in mind. 
-This framework was heavily inspired by the excellent Dancer::Plugin::Auth::Extensible 
-framework which I'd highly recommend as it for your consideration. 
+This framework was heavily inspired by the excellent L<Dancer::Plugin::Auth::Extensible> 
+framework which I'd highly recommend. 
 YARBAC was designed to support secure password checking, enforced password hashing, 
 multiple authentication realms and the ability to create your own backend provider. 
-YARBAC was also designed to to be as flexialbe and as feature rich as possible 
+YARBAC was also designed to to be as flexible and as feature rich as possible 
 in the hope that I'll never have to write RBAC code for Dancer again. :) 
 While similar to Extensible in some ways, this framework has some significantly 
 different approaches. 
@@ -1089,7 +1102,7 @@ returns false.
     # Optionally user other realm than current logged in user:
     # user_has_any_role( { role_names => [ 'admin', 'managers' ] }, { realm => 'admins' } );
 
-    my $has_role = user_has_any_role( { role_name => [ 'admin', 'managers' ] } );
+    my $has_role = user_has_any_role( { role_names => [ 'admin', 'managers' ] } );
 
     unless ( $has_role ) {
         # User doesn't have the role.
@@ -1650,10 +1663,10 @@ If the no groups exist returns false.
 
   get '/revoke/user/role' => sub {
     # Optionally use other realm than current logged in user:
-    # revoke_user_role( { username => 'sam' }, { realm => 'admins' } );
+    # revoke_user_role( { username => 'sam', role_name => 'admin' }, { realm => 'admins' } );
     #
     # Optionally use other realm than current logged in user:
-    my $revoke = revoke_user_role( { username => 'sam' } );
+    my $revoke = revoke_user_role( { username => 'sam', role_name => 'admin' } );
        
     if ( $revoke ) {
         # success
@@ -1985,6 +1998,22 @@ is false.
 
 =back
 
+=head1 MISCELLANEOUS
+
+=over
+
+=item provider - Returns the backend provider object
+
+  get '/provider' => sub {
+    my $provider = provider();
+    #.......         
+  };
+
+Keyword 'provider' returns the backend provider object.
+Wouldn't recommend it without a good reason.
+
+=back
+
 =head1 AUTHOR
 
 Sarah Fuller <sarah@averna.id.au>
